django-iprestrict
=================
[![Build Status](https://travis-ci.org/muccg/django-iprestrict.png?branch=master)](https://travis-ci.org/muccg/django-iprestrict) [![PyPI](https://badge.fury.io/py/django-iprestrict.svg)](https://pypi.python.org/pypi/django-iprestrict) [![Documentation Status](https://readthedocs.org/projects/django-iprestrict/badge/?version=latest)](http://django-iprestrict.readthedocs.org/en/latest/?badge=latest)

Django app + middleware to restrict access to all or sections of a Django project by client IP ranges.

The full instructions for installation and use are here:

  http://django-iprestrict.readthedocs.org/en/latest/
